@@ -110,21 +110,18 @@ impl Dispatcher {
                 sender,
                 message,
                 dest_info,
-            } => {
-                let our_local_ip = self.comm.local_addr().ip();
-                Ok(self
-                    .core
-                    .write()
-                    .await
-                    .handle_section_info_msg(sender, message, dest_info, our_local_ip)
-                    .await)
-            }
+            } => Ok(self
+                .core
+                .write()
+                .await
+                .handle_section_info_msg(sender, message, dest_info)
+                .await),
             Command::HandleTimeout(token) => self.core.write().await.handle_timeout(token),
-            Command::HandleAgreement { proposal, proof } => {
+            Command::HandleAgreement { proposal, signed } => {
                 self.core
                     .write()
                     .await
-                    .handle_agreement(proposal, proof)
+                    .handle_agreement(proposal, signed)
                     .await
             }
             Command::HandleConnectionLost(addr) => {
@@ -139,11 +136,11 @@ impl Dispatcher {
                 .write()
                 .await
                 .handle_dkg_outcome(section_auth, outcome),
-            Command::HandleDkgFailure(proofs) => self
+            Command::HandleDkgFailure(signeds) => self
                 .core
                 .write()
                 .await
-                .handle_dkg_failure(proofs)
+                .handle_dkg_failure(signeds)
                 .map(|command| vec![command]),
             Command::SendMessage {
                 recipients,
@@ -180,16 +177,16 @@ impl Dispatcher {
             Command::SetJoinsAllowed(joins_allowed) => {
                 self.core.read().await.set_joins_allowed(joins_allowed)
             }
-            Command::TestConnectivity {
+            Command::ProposeOnline {
                 mut peer,
                 previous_name,
-                their_knowledge,
+                destination_key,
             } => {
                 peer.set_reachable(self.comm.is_reachable(peer.addr()).await.is_ok());
                 self.core
                     .read()
                     .await
-                    .make_online_proposal(peer, previous_name, their_knowledge)
+                    .make_online_proposal(peer, previous_name, destination_key)
                     .await
             }
             Command::ProposeOffline(name) => self.core.read().await.propose_offline(name),
