@@ -29,7 +29,6 @@ use crate::{
 };
 use anyhow::Result;
 use assert_matches::assert_matches;
-use bls_signature_aggregator::Proof;
 use bytes::Bytes;
 use resource_proof::ResourceProof;
 use secured_linked_list::SecuredLinkedList;
@@ -37,12 +36,12 @@ use sn_data_types::{Keypair, PublicKey};
 use sn_messaging::{
     location::{Aggregation, Itinerary},
     node::{
-        JoinRequest, MemberInfo, Network, Peer, PeerState, PlainMessage, Proposal, Proven,
-        RelocateDetails, RelocatePayload, ResourceProofResponse, RoutingMsg, Section,
-        SectionAuthorityProvider, SignedRelocateDetails, Variant,
+        JoinRequest, JoinResponse, MemberInfo, Network, Peer, PeerState, PlainMessage, Proposal,
+        Proven, RelocateDetails, RelocatePayload, ResourceProofResponse, RoutingMsg, Section,
+        Signed, SignedRelocateDetails, Variant,
     },
-    section_info::{GetSectionResponse, Message as SectionInfoMsg},
-    DestInfo, DstLocation, MessageType, SrcLocation,
+    section_info::{GetSectionResponse, SectionInfoMsg},
+    DestInfo, DstLocation, MessageType, SectionAuthorityProvider, SrcLocation,
 };
 use std::{
     collections::{BTreeSet, HashSet},
@@ -71,10 +70,7 @@ async fn receive_matching_get_section_request_as_elder() -> Result<()> {
     );
     let new_node_name = new_node.name();
 
-    let message = SectionInfoMsg::GetSectionQuery {
-        public_key: PublicKey::from(new_node.keypair.public),
-        is_node: true,
-    };
+    let message = SectionInfoMsg::GetSectionQuery(PublicKey::from(new_node.keypair.public));
 
     let mut commands = dispatcher
         .handle_command(Command::HandleSectionInfoMsg {
@@ -112,11 +108,6 @@ async fn receive_mismatching_get_section_request_as_adult() -> Result<()> {
 
     let sk_set = SecretKeySet::random();
     let (section_auth, _, _) = gen_section_authority_provider(good_prefix, ELDER_SIZE);
-    let elders_addrs: Vec<_> = section_auth
-        .elders()
-        .iter()
-        .map(|(name, addr)| (*name, *addr))
-        .collect();
     let (section, _) = create_section(&sk_set, &section_auth)?;
 
     let node = create_node(MIN_ADULT_AGE);
@@ -142,10 +133,7 @@ async fn receive_mismatching_get_section_request_as_adult() -> Result<()> {
     let new_node_comm = create_comm().await?;
     let new_node_addr = new_node_comm.our_connection_info();
 
-    let message = SectionInfoMsg::GetSectionQuery {
-        public_key: random_pk,
-        is_node: true,
-    };
+    let message = SectionInfoMsg::GetSectionQuery(random_pk);
 
     let mut commands = dispatcher
         .handle_command(Command::HandleSectionInfoMsg {
@@ -170,8 +158,8 @@ async fn receive_mismatching_get_section_request_as_adult() -> Result<()> {
     assert_eq!(recipients, [(new_node_name, new_node_addr)]);
     assert_matches!(
         message,
-        SectionInfoMsg::GetSectionResponse(GetSectionResponse::Redirect(addrs)) => {
-            assert_eq!(addrs, elders_addrs)
+        SectionInfoMsg::GetSectionResponse(GetSectionResponse::Redirect(received_section_auth)) => {
+            assert_eq!(received_section_auth, section_auth)
         }
     );
 
@@ -217,14 +205,20 @@ async fn receive_join_request_without_resource_proof_response() -> Result<()> {
         .await?
         .into_iter();
 
-    let response_message = assert_matches!(
+    let response_message_variant = assert_matches!(
         commands.next(),
-        Some(Command::SendMessage { message: MessageType::Routing { msg, .. }, .. }) => msg
+        Some(Command::SendMessage {
+            message: MessageType::Routing {
+                msg: RoutingMsg { variant: Variant::JoinResponse(variant), .. },
+                ..
+            },
+            ..
+        }) => variant
     );
 
     assert_matches!(
-        response_message.variant(),
-        Variant::ResourceChallenge { .. }
+        *response_message_variant,
+        JoinResponse::ResourceChallenge { .. }
     );
 
     Ok(())
@@ -282,17 +276,17 @@ async fn receive_join_request_with_resource_proof_response() -> Result<()> {
 
     let mut test_connectivity = false;
     for command in commands {
-        if let Command::TestConnectivity {
+        if let Command::ProposeOnline {
             peer,
             previous_name,
-            their_knowledge,
+            destination_key,
         } = command
         {
             assert_eq!(*peer.name(), new_node.name());
             assert_eq!(*peer.addr(), new_node.addr);
             assert_eq!(peer.age(), FIRST_SECTION_MIN_AGE);
             assert_eq!(previous_name, None);
-            assert_eq!(their_knowledge, None);
+            assert_eq!(destination_key, None);
 
             test_connectivity = true;
         }
@@ -349,7 +343,7 @@ async fn receive_join_request_from_relocated_node() -> Result<()> {
     let proof_chain = SecuredLinkedList::new(section_key);
     let relocate_message = RoutingMsg::section_src(
         relocate_message,
-        Proof {
+        Signed {
             public_key: section_key,
             signature,
         },
@@ -387,15 +381,15 @@ async fn receive_join_request_from_relocated_node() -> Result<()> {
     let mut test_connectivity = false;
 
     for command in commands {
-        if let Command::TestConnectivity {
+        if let Command::ProposeOnline {
             peer,
             previous_name,
-            their_knowledge,
+            destination_key,
         } = command
         {
             assert_eq!(peer, relocated_node.peer());
             assert_eq!(previous_name, Some(relocated_node_old_name));
-            assert_eq!(their_knowledge, Some(section_key));
+            assert_eq!(destination_key, Some(section_key));
 
             test_connectivity = true;
         }
@@ -425,19 +419,20 @@ async fn aggregate_proposals() -> Result<()> {
     let proposal = Proposal::Online {
         member_info,
         previous_name: None,
-        their_knowledge: None,
+        destination_key: None,
     };
 
     for index in 0..THRESHOLD {
-        let proof_share = proposal.prove(pk_set.clone(), index, &sk_set.secret_key_share(index))?;
+        let signed_share =
+            proposal.prove(pk_set.clone(), index, &sk_set.secret_key_share(index))?;
         let message = RoutingMsg::single_src(
             &nodes[index],
             DstLocation::DirectAndUnrouted,
             Variant::Propose {
                 content: proposal.clone(),
-                proof_share,
+                signed_share,
             },
-            section_auth.section_key,
+            section_auth.section_key(),
         )?;
 
         let commands = dispatcher
@@ -453,7 +448,7 @@ async fn aggregate_proposals() -> Result<()> {
         assert!(commands.is_empty());
     }
 
-    let proof_share = proposal.prove(
+    let signed_share = proposal.prove(
         pk_set.clone(),
         THRESHOLD,
         &sk_set.secret_key_share(THRESHOLD),
@@ -463,9 +458,9 @@ async fn aggregate_proposals() -> Result<()> {
         DstLocation::DirectAndUnrouted,
         Variant::Propose {
             content: proposal.clone(),
-            proof_share,
+            signed_share,
         },
-        section_auth.section_key,
+        section_auth.section_key(),
     )?;
     let mut commands = dispatcher
         .handle_command(Command::HandleMessage {
@@ -537,10 +532,10 @@ async fn handle_agreement_on_online_of_elder_candidate() -> Result<()> {
         let mut peer = peer;
         peer.set_reachable(true);
         let member_info = MemberInfo::joined(peer);
-        let proof = prove(sk_set.secret_key(), &member_info)?;
+        let signed = prove(sk_set.secret_key(), &member_info)?;
         let _ = section.update_member(Proven {
             value: member_info,
-            proof,
+            signed,
         });
         if peer.age() == MIN_AGE + 2 {
             let _ = expected_new_elders.insert(peer);
@@ -565,12 +560,12 @@ async fn handle_agreement_on_online_of_elder_candidate() -> Result<()> {
     let proposal = Proposal::Online {
         member_info,
         previous_name: Some(XorName::random()),
-        their_knowledge: Some(sk_set.secret_key().public_key()),
+        destination_key: Some(sk_set.secret_key().public_key()),
     };
-    let proof = prove(sk_set.secret_key(), &proposal.as_signable())?;
+    let signed = prove(sk_set.secret_key(), &proposal.as_signable())?;
 
     let commands = dispatcher
-        .handle_command(Command::HandleAgreement { proposal, proof })
+        .handle_command(Command::HandleAgreement { proposal, signed })
         .await?;
 
     // Verify we sent a `DkgStart` message with the expected participants.
@@ -587,7 +582,7 @@ async fn handle_agreement_on_online_of_elder_candidate() -> Result<()> {
             _ => continue,
         };
 
-        let actual_elder_candidates = match message.variant() {
+        let actual_elder_candidates = match message.variant {
             Variant::DkgStart {
                 elder_candidates, ..
             } => elder_candidates,
@@ -621,12 +616,12 @@ async fn handle_online_command(
     let proposal = Proposal::Online {
         member_info,
         previous_name: None,
-        their_knowledge: None,
+        destination_key: None,
     };
-    let proof = prove(sk_set.secret_key(), &proposal.as_signable())?;
+    let signed = prove(sk_set.secret_key(), &proposal.as_signable())?;
 
     let commands = dispatcher
-        .handle_command(Command::HandleAgreement { proposal, proof })
+        .handle_command(Command::HandleAgreement { proposal, signed })
         .await?;
 
     let mut status = HandleOnlineStatus {
@@ -644,14 +639,17 @@ async fn handle_online_command(
             _ => continue,
         };
 
-        match message.variant() {
-            Variant::NodeApproval {
-                section_auth: proven_section_auth,
-                ..
-            } => {
-                assert_eq!(proven_section_auth.value, *section_auth);
-                assert_eq!(recipients, [(*peer.name(), *peer.addr())]);
-                status.node_approval_sent = true;
+        match message.variant {
+            Variant::JoinResponse(response) => {
+                if let JoinResponse::Approval {
+                    section_auth: proven_section_auth,
+                    ..
+                } = *response
+                {
+                    assert_eq!(proven_section_auth.value, *section_auth);
+                    assert_eq!(recipients, [(*peer.name(), *peer.addr())]);
+                    status.node_approval_sent = true;
+                }
             }
             Variant::Relocate(details) => {
                 if details.pub_id != *peer.name() {
@@ -764,10 +762,10 @@ async fn handle_agreement_on_offline_of_non_elder() -> Result<()> {
         state: PeerState::Left,
     };
     let proposal = Proposal::Offline(member_info);
-    let proof = prove(sk_set.secret_key(), &proposal.as_signable())?;
+    let signed = prove(sk_set.secret_key(), &proposal.as_signable())?;
 
     let _ = dispatcher
-        .handle_command(Command::HandleAgreement { proposal, proof })
+        .handle_command(Command::HandleAgreement { proposal, signed })
         .await?;
 
     assert_matches!(event_rx.recv().await, Some(Event::MemberLeft { name, age, }) => {
@@ -808,10 +806,10 @@ async fn handle_agreement_on_offline_of_elder() -> Result<()> {
 
     // Handle agreement on the Offline proposal
     let proposal = Proposal::Offline(remove_member_info);
-    let proof = prove(sk_set.secret_key(), &proposal.as_signable())?;
+    let signed = prove(sk_set.secret_key(), &proposal.as_signable())?;
 
     let commands = dispatcher
-        .handle_command(Command::HandleAgreement { proposal, proof })
+        .handle_command(Command::HandleAgreement { proposal, signed })
         .await?;
 
     // Verify we sent a `DkgStart` message with the expected participants.
@@ -827,7 +825,7 @@ async fn handle_agreement_on_offline_of_elder() -> Result<()> {
             _ => continue,
         };
 
-        let actual_elder_candidates = match message.variant() {
+        let actual_elder_candidates = match message.variant {
             Variant::DkgStart {
                 elder_candidates, ..
             } => elder_candidates,
@@ -934,7 +932,7 @@ async fn handle_untrusted_message(source: UntrustedMessageSource) -> Result<()>
     let signature = sk1.sign(&bincode::serialize(&message.as_signable())?);
     let original_message = RoutingMsg::section_src(
         message,
-        Proof {
+        Signed {
             public_key: pk1,
             signature,
         },
@@ -966,7 +964,7 @@ async fn handle_untrusted_message(source: UntrustedMessageSource) -> Result<()>
             continue;
         };
 
-        if let Variant::BouncedUntrustedMessage { msg, dest_info } = message.variant() {
+        if let Variant::BouncedUntrustedMessage { msg, dest_info } = message.variant {
             assert_eq!(
                 recipients
                     .into_iter()
@@ -974,7 +972,7 @@ async fn handle_untrusted_message(source: UntrustedMessageSource) -> Result<()>
                     .collect::<Vec<_>>(),
                 expected_recipients
             );
-            assert_eq!(**msg, original_message);
+            assert_eq!(*msg, original_message);
             assert_eq!(dest_info.dest_section_pk, pk0);
 
             bounce_sent = true;
@@ -1007,7 +1005,7 @@ async fn handle_bounced_untrusted_message() -> Result<()> {
     let node = nodes.remove(0);
     let node_name = node.name();
 
-    // Create the original message whose bounce we want to test. Attach a proof that starts
+    // Create the original message whose bounce we want to test. Attach a signed that starts
     // at `pk1`.
     let other_node = Node::new(
         crypto::gen_keypair(&Prefix::default().range_inclusive(), MIN_ADULT_AGE),
@@ -1027,7 +1025,7 @@ async fn handle_bounced_untrusted_message() -> Result<()> {
     let proof_chain = chain.truncate(1);
     let original_message = RoutingMsg::section_src(
         original_message,
-        Proof {
+        Signed {
             public_key: pk1,
             signature,
         },
@@ -1078,11 +1076,11 @@ async fn handle_bounced_untrusted_message() -> Result<()> {
             _ => continue,
         };
 
-        match message.variant() {
+        match message.variant {
             Variant::UserMessage(content) => {
                 assert_eq!(recipients, [(other_node.name(), other_node.addr)]);
                 assert_eq!(*content, original_message_content);
-                assert_eq!(message.section_pk(), pk0);
+                assert_eq!(message.section_pk, pk0);
 
                 message_sent = true;
             }
@@ -1244,9 +1242,9 @@ async fn handle_untrusted_sync() -> Result<()> {
             _ => continue,
         };
 
-        match message.variant() {
+        match message.variant {
             Variant::BouncedUntrustedMessage { msg, .. } => {
-                assert_eq!(**msg, orig_message);
+                assert_eq!(*msg, orig_message);
                 assert_eq!(recipients, [(sender.name(), sender.addr)]);
                 bounce_sent = true;
             }
@@ -1342,7 +1340,7 @@ async fn handle_bounced_untrusted_sync() -> Result<()> {
             _ => continue,
         };
 
-        match message.variant() {
+        match message.variant {
             Variant::Sync { section, .. } => {
                 assert_eq!(recipients, [(sender.name(), sender.addr)]);
                 assert!(section.chain().has_key(&pk0));
@@ -1396,9 +1394,9 @@ async fn relocation(relocated_peer_role: RelocatedPeerRole) -> Result<()> {
         RelocatedPeerRole::NonElder => non_elder_peer,
     };
 
-    let (proposal, proof) = create_relocation_trigger(sk_set.secret_key(), relocated_peer.age())?;
+    let (proposal, signed) = create_relocation_trigger(sk_set.secret_key(), relocated_peer.age())?;
     let commands = dispatcher
-        .handle_command(Command::HandleAgreement { proposal, proof })
+        .handle_command(Command::HandleAgreement { proposal, signed })
         .await?;
 
     let mut relocate_sent = false;
@@ -1423,7 +1421,7 @@ async fn relocation(relocated_peer_role: RelocatedPeerRole) -> Result<()> {
         }
         match relocated_peer_role {
             RelocatedPeerRole::NonElder => {
-                let details = match message.variant() {
+                let details = match message.variant {
                     Variant::Relocate(details) => details,
                     _ => continue,
                 };
@@ -1432,7 +1430,7 @@ async fn relocation(relocated_peer_role: RelocatedPeerRole) -> Result<()> {
                 assert_eq!(details.age, relocated_peer.age() + 1);
             }
             RelocatedPeerRole::Elder => {
-                let promise = match message.variant() {
+                let promise = match message.variant {
                     Variant::RelocatePromise(promise) => promise,
                     _ => continue,
                 };
@@ -1492,12 +1490,12 @@ async fn message_to_self(dst: MessageDst) -> Result<()> {
 
     assert_matches!(&commands[..], [Command::HandleMessage { sender, message, dest_info }] => {
         assert_eq!(sender.as_ref(), Some(peer.addr()));
-        assert_eq!(message.src().src_location(), src);
-        assert_eq!(message.dst(), &dst);
+        assert_eq!(message.src.src_location(), src);
+        assert_eq!(&message.dst, &dst);
         assert_eq!(dest_info.dest, dst_name);
         assert_matches!(
-            message.variant(),
-            Variant::UserMessage(actual_content) if actual_content == &content
+            &message.variant,
+            Variant::UserMessage(actual_content) if Bytes::from(actual_content.clone()) == content
         );
     });
 
@@ -1552,7 +1550,7 @@ async fn handle_elders_update() -> Result<()> {
     let signature = sk_set0
         .secret_key()
         .sign(&bincode::serialize(&proposal.as_signable())?);
-    let proof = Proof {
+    let signed = Signed {
         signature,
         public_key: pk0,
     };
@@ -1562,7 +1560,7 @@ async fn handle_elders_update() -> Result<()> {
     let dispatcher = Dispatcher::new(state, create_comm().await?);
 
     let commands = dispatcher
-        .handle_command(Command::HandleAgreement { proposal, proof })
+        .handle_command(Command::HandleAgreement { proposal, signed })
         .await?;
 
     let mut sync_actual_recipients = HashSet::new();
@@ -1577,8 +1575,8 @@ async fn handle_elders_update() -> Result<()> {
             _ => continue,
         };
 
-        let section = match message.variant() {
-            Variant::Sync { section, .. } => section,
+        let section = match message.variant {
+            Variant::Sync { ref section, .. } => section,
             _ => continue,
         };
 
@@ -1666,12 +1664,12 @@ async fn handle_demote_during_split() -> Result<()> {
         let signature = sk_set_v0
             .secret_key()
             .sign(&bincode::serialize(&proposal.as_signable())?);
-        let proof = Proof {
+        let signed = Signed {
             signature,
             public_key: sk_set_v0.secret_key().public_key(),
         };
 
-        Ok(Command::HandleAgreement { proposal, proof })
+        Ok(Command::HandleAgreement { proposal, signed })
     };
 
     // Handle agreement on `OurElders` for prefix-0.
@@ -1702,7 +1700,7 @@ async fn handle_demote_during_split() -> Result<()> {
             _ => continue,
         };
 
-        if matches!(message.variant(), Variant::Sync { .. }) {
+        if matches!(message.variant, Variant::Sync { .. }) {
             sync_recipients.extend(recipients);
         }
     }
@@ -1814,23 +1812,23 @@ fn create_section(
 // NOTE: recommended to call this with low `age` (4 or 5), otherwise it might take very long time
 // to complete because it needs to generate a signature with the number of trailing zeroes equal to
 // (or greater that) `age`.
-fn create_relocation_trigger(sk: &bls::SecretKey, age: u8) -> Result<(Proposal, Proof)> {
+fn create_relocation_trigger(sk: &bls::SecretKey, age: u8) -> Result<(Proposal, Signed)> {
     loop {
         let proposal = Proposal::Online {
             member_info: MemberInfo::joined(create_peer(MIN_ADULT_AGE)),
             previous_name: Some(rand::random()),
-            their_knowledge: None,
+            destination_key: None,
         };
 
         let signature = sk.sign(&bincode::serialize(&proposal.as_signable())?);
 
         if relocation::check(age, &signature) && !relocation::check(age + 1, &signature) {
-            let proof = Proof {
+            let signed = Signed {
                 public_key: sk.public_key(),
                 signature,
             };
 
-            return Ok((proposal, proof));
+            return Ok((proposal, signed));
         }
     }
 }
